@@ -118,4 +118,4 @@ def L_SUE_Aggregator(ue_reports, eps_perm, eps_1):
     # Re-normalized estimated frequency
     norm_est_freq = est_freq / sum(est_freq)
 
-    return norm_est_freq
+    return np.nan_to_num(norm_est_freq)
